##############################################
## PopDensity_Repression.R
## Purpose: Repression = f(population density)
## Date: December 4, 2016
##############################################

rm(list = ls()); gc()

##############################################
## LOADING PREPPED SCAD DATA:
##############################################

setwd(data_dir)
load("SCAD/Prepared_SCAD.Rdata")

# scad_dt <- scad_dt[!is.na(urban)]

scad_dt[npart <= 0, npart := NA]
scad_dt[, .N, by = npart]

##############################################
## 1(Repression) = f(Pop Density)
##############################################

m1 <- felm(any_repress ~ factor(npart) |
    ccode + eyr | 0 | ccode,
    data = scad_dt)

m1_cntrls <- felm(any_repress ~ factor(npart) |
    leader_code + ccode + eyr +
    issue_type + govt_target + tactic + event_type |
    0 | ccode,
    data = scad_dt)

##############################################
# Coefficient Plot:
m1_dt <- summary(m1_cntrls)$coefficients %>% data.table()
setnames(m1_dt, c("beta", "se", "tstat", "pval"))

# Conf Intervals:
m1_dt[, lb := beta - 1.96 * se]
m1_dt[, lb_90 := beta - 1.65 * se]
m1_dt[, ub := beta + 1.96 * se]
m1_dt[, ub_90 := beta + 1.65 * se]

m1_dt[, npart_cat := 2:7]
m1_dt[, npart_lbl := c("[10,100]", "(100,1k]", "(1k,10k]", "(10k, 100k]", "(100k, 1mil]", "Over 1mil")]

##############################################
## FIGURE 2
############################################## 

setwd(figs_dir)
pdf(file = "PrRepress_Npart.pdf", width = 9)
ggplot(data = m1_dt, aes(x = npart_cat, y = beta)) +
    geom_errorbar(aes(ymin = lb, ymax = ub), width = .2) +
    geom_errorbar(aes(ymin = lb_90, ymax = ub_90), width = 0, lwd = 1.5) +
    geom_point(size = 3) +
    geom_point(data = m1_dt[npart_cat == 2], aes(x = npart_cat, y = beta),
        size = 10, shape = 1) +
    geom_hline(yintercept = 0, lty = 2) +
    scale_x_continuous("Participants",
        breaks = 2:7, labels = m1_dt[, npart_lbl]) +
    scale_y_continuous("Estimate") +
    annotate("text", x = 3.4, y = m1_dt[npart_cat == 2, beta] - .05,
        family = "serif", fontface = "bold", size = 5.5,
        label = "Increased Pr(Protest) Relative\nto Protests with 0-10 Participants") +
    theme_bw() + opts
dev.off()

#############################################

m2 <- felm(any_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt)

m2_cntrls <- felm(any_repress ~ ln_popdens |
    leader_code + ccode + eyr +
    issue_type + govt_target + tactic + event_type |
    0 | ccode,
    data = scad_dt)

m2_group <- felm(any_repress ~ factor(npart) + ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt)

##############################################
## ADDITIONAL MODEL INFORMATION
##############################################

m1_ct <- scad_dt[!is.na(any_repress) & !is.na(npart) &
    !is.na(ccode) & !is.na(eyr),
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_,
    ngrp = NA_integer_)]

m1_cntrls_ct <- scad_dt[!is.na(any_repress) & !is.na(npart) &
    !is.na(ccode) & !is.na(eyr) &
    !is.na(issue_type) & !is.na(govt_target) &
    !is.na(tactic) & !is.na(event_type),
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = length(unique(leader_code)),
    ngrp = NA_integer_)]

m2_ct <- scad_dt[!is.na(any_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr),
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_,
    ngrp = NA_integer_)]

m2_cntrls_ct <- scad_dt[!is.na(any_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) &
    !is.na(issue_type) & !is.na(govt_target) &
    !is.na(tactic) & !is.na(event_type),
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = length(unique(leader_code)),
    ngrp = NA_integer_)]

m2_group_ct <- scad_dt[!is.na(any_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & !is.na(npart),
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_,
    ngrp = NA_integer_)]

ct_dt <- rbindlist(list(m1_ct, m1_cntrls_ct, m2_ct, m2_cntrls_ct, m2_group_ct))

##############################################
## REGRESSION TABLE
##############################################

# Covariate Labels
covars <- c(m1_dt[, npart_lbl], "Log(Pop. Density)")

# Counts for bottom of table:
cntry_FE <- c("Country FEs", format(ct_dt[, ncntry],
    big.mark = ",", trim = TRUE))
year_FE <- c("Year FEs", format(ct_dt[, nyear], big.mark = ",", trim = TRUE))
# group_FE <- c("Ethnic Group FEs", format(ct_dt[, ngrp], big.mark = ",", trim = TRUE))
leader_FE <- c("Leader FEs", format(ct_dt[, nldr],
    big.mark = ",", trim = TRUE))

event_cntrls <- c("\\midrule Event Controls", "", "\\checkmark", "", "\\checkmark")

add_lines <- list(year_FE, cntry_FE, leader_FE, event_cntrls)
add_lines <- lapply(add_lines, function(x) {x[x == "NA"] <- ""; x})

##############################################
## TABLE 2:
############################################## 

setwd(tabs_dir)
stargazer(list(m1, m1_cntrls, m2, m2_cntrls, m2_group),
    dep.var.labels = c("$\\mathbb{1}$(Repression)"),
    covariate.labels = covars,
    keep.stat = "n",
    p.auto = TRUE,
    star.cutoffs = c(.1, .05),
    star.char = c("\\dagger", "*"),
    add.lines = add_lines,
    notes = "Robust std. errors clustered on country; $^{\\dagger} p <$ 0.1, $^*p <$ 0.05",
    notes.append = FALSE,
    table.placement = "ht!",
    digits = 3,
    label = "tab:popdensity_repression",
    title = "Pr(Repression) by Protest Size and Population Density",
    out = "PopDensity_Repression.tex")

##############################################
## TABLE 3:
##############################################

setwd(tabs_dir)
vars <- c("$\\mathbb{1}$(Repression)", "Participants", "Log(Pop. Density)", "Year")
stargazer(scad_dt[,.(any_repress, npart, ln_popdens, eyr)],
    covariate.labels = vars,
    label = "tab:sumstats_popdensity_repression",
    title = "Summary Statistics: Pr(Repression) by Protest Size and Population Density",
    digits = 3,
    table.placement = "ht!",
    out = "SumStats_PopDensity_Repression.tex")
