##############################################
## PopDensity_Lethal.R
## Purpose: Lethal Repression = f(population density)
## Date: December 4, 2016 
##############################################

rm(list = ls()); gc()

##############################################
## LOADING PREPPED SCAD DATA:
##############################################

setwd(data_dir)
load("SCAD/Prepared_SCAD.Rdata")

# Limiting to events with repression:
scad_dt <- scad_dt[any_repress == 1]

##############################################
## 1(Lethal) = f(Pop Density)
##############################################

m1 <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt)

m2 <- felm(lethal_repress ~ ln_popdens |
    leader_code + ccode + eyr +
    issue_type + govt_target + tactic + event_type |
    0 | ccode,
    data = scad_dt)

m3 <- felm(lethal_repress ~ ln_popdens |
    groupname + eyr | 0 | ccode,
    data = scad_dt)

m4 <- felm(lethal_repress ~ ln_popdens |
    leader_code + groupname + eyr +
    issue_type + govt_target + tactic + event_type |
    0 | ccode,
    data = scad_dt)

m5 <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt[urban == 1])

# Report this in the text:
felm(lethal_repress ~ factor(npart) + ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt) %>% summary()
# Call:
#    felm(formula = lethal_repress ~ factor(npart) + ln_popdens |
#     ccode + eyr | 0 | ccode, data = scad_dt)
# Coefficients:
#                Estimate Cluster s.e. t value Pr(>|t|)
# factor(npart)2 -0.07968      0.07778  -1.024 0.305911
# factor(npart)3 -0.10337      0.05975  -1.730 0.083943 .
# factor(npart)4  0.02956      0.06048   0.489 0.625100
# factor(npart)5  0.13121      0.07015   1.870 0.061760 .
# factor(npart)6  0.25546      0.16279   1.569 0.116937
# factor(npart)7 -0.14974      0.08371  -1.789 0.073992 .
# ln_popdens     -0.04188      0.01121  -3.735 0.000199 ***
# Residual standard error: 0.3774 on 912 degrees of freedom

##############################################
## ADDITIONAL MODEL INFORMATION
##############################################

m1_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr),
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_,
    ngrp = NA_integer_)]

m2_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) &
    !is.na(issue_type) & !is.na(govt_target) & !is.na(tactic) & !is.na(event_type),
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = length(unique(leader_code)),
    ngrp = NA_integer_)]

m3_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(groupname) & !is.na(eyr),
    list(nyear = length(unique(eyr)),
    ncntry = NA_integer_,
    nldr = NA_integer_,
    ngrp = length(unique(groupname)))]

m4_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(groupname) & !is.na(eyr) &
    !is.na(issue_type) & !is.na(govt_target) & !is.na(tactic) & !is.na(event_type),
    list(nyear = length(unique(eyr)),
    ncntry = NA_integer_,
    nldr = length(unique(leader_code)),
    ngrp = length(unique(groupname)))]

m5_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & urban == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_,
    ngrp = NA_integer_)]

ct_dt <- rbindlist(list(m1_ct, m2_ct, m3_ct, m4_ct, m5_ct))

##############################################
## REGRESSION TABLE
##############################################

# Covariate Labels
covars <- c("Log(Pop. Density)")

# Model Labels:
m_labs <- c("1", "2", "3", "4", "5 (Urban Sample)")

# Counts for bottom of table:
cntry_FE <- c("Country FEs", format(ct_dt[, ncntry],
    big.mark = ",", trim = TRUE))
year_FE <- c("Year FEs", format(ct_dt[, nyear], big.mark = ",", trim = TRUE))
group_FE <- c("Ethnic Group FEs", format(ct_dt[, ngrp], big.mark = ",", trim = TRUE))
leader_FE <- c("Leader FEs", format(ct_dt[, nldr],
    big.mark = ",", trim = TRUE))

event_cntrls <- c("\\midrule Event Controls", "", "\\checkmark", "", "\\checkmark")

add_lines <- list(year_FE, cntry_FE, leader_FE, group_FE, event_cntrls)
add_lines <- lapply(add_lines, function(x) {x[x == "NA"] <- ""; x})

##############################################
## TABLE 4:
############################################## 

setwd(tabs_dir)
stargazer(list(m1, m2, m3, m4, m5),
    dep.var.labels = c("$\\mathbb{1}$(Lethal Repression)"),
    covariate.labels = covars,
    column.labels = m_labs,
    model.numbers = FALSE,
    keep.stat = "n",
    p.auto = TRUE,
    star.cutoffs = c(.1, .05),
    star.char = c("\\dagger", "*"),
    add.lines = add_lines,
    notes = "Robust std. errors clustered on country; $^{\\dagger} p <$ 0.1, $^*p <$ 0.05",
    notes.append = FALSE,
    table.placement = "ht!",
    digits = 3,
    label = "tab:popdensity_lethal",
    title = "Pr(Lethal Repression) by Population Density",
    out = "PopDensity_Lethal.tex")

##############################################
## Table 5:
##############################################

setwd(tabs_dir)
vars <- c("$\\mathbb{1}$(Lethal)", "Log(Pop. Density)", "Year")
stargazer(scad_dt[,.(lethal_repress, ln_popdens, eyr)],
    covariate.labels = vars,
    label = "tab:sumstats_popdensity_lethal",
    title = "Summary Statistics: Pr(Lethal) by Population Density",
    digits = 3,
    table.placement = "ht!",
    out = "SumStats_PopDensity_Lethal.tex")
